@@ -517,8 +517,13 @@ load_bugzilla (const char *filename)
 	bts->severity_node   = gnome_config_get_string ("severity_node=severities");
 	bts->severity_item   = gnome_config_get_string ("severity_item=severity");
 	bts->severity_header = gnome_config_get_string ("severity_header=Severity");
-	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME )
-		bugzilla_get_md5sums (bts, gnome_config_get_string ("md5sums"));
+	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME ) {
+		s = gnome_config_get_string ("md5sums");
+		if (s && s!=NULL) {
+			bugzilla_get_md5sums (bts, s);
+			g_free (s);
+		}
+	}
 	
 	bts->products_xml = get_xml_file (bts, "products", 
 					  bts->products_xml_md5,
